:orphan:

.. _ug-FrameworkInfo:


=================================
FrameworkInfo Class
=================================

**The following API can be used to pass MCT framework-related information to use when optimizing the network**

.. autoclass:: model_compression_toolkit.FrameworkInfo

